An example program for the mDot that blinks LED1 and prints a message to the debug port.

Dependencies:   mbed

Revision:
1:34c1fcb8ea5a
Parent:
0:fdc94d24e54a
--- a/main.cpp	Wed Jun 10 16:56:38 2015 +0000
+++ b/main.cpp	Tue Jul 07 14:09:33 2015 +0000
@@ -1,12 +1,20 @@
 /*************************************
  * This simple example program blinks
  * LED1 and prints a message out the
  * USB debug port.
  ************************************/
 
 #include "mbed.h"
 
+// Uncomment this line if using a full sized UDK2.0 instead of a Micro UDK
+// #define UDK2 1
+
+#ifdef UDK2
 DigitalOut led(LED1);
+#else
+DigitalOut led(XBEE_RSSI);
+#endif
+
 Ticker tick;
 
 // callback function to change LED state
@@ -1,12 +1,20 @@
 /*************************************
  * This simple example program blinks
- * LED1 and prints a message out the
+ * a LED and prints a message out the
  * USB debug port.
  ************************************/